==> spip_4.0.4.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_lb.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=lb
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_effacer_referers' => 'Nëmmen d’Linken déi erakomme läschen',
	'bouton_effacer_statistiques' => 'All d’Statistike läschen',

	// C
	'csv' => 'CSV',

	// I
	'icone_evolution_visites' => 'Entwécklung vun de Visiten<br />@visites@ Visiten',
	'icone_repartition_actuelle' => 'Déi aktuell Verdeelung weisen',
	'icone_repartition_visites' => 'Verdeelung vun de Visiten',
	'icone_statistiques_visites' => 'Statistik',
	'info_affichier_visites_articles_plus_visites' => 'D’Visite fir <b>déi am meeschte gefroten Artikelen zënter dem Ufank</b> weisen:',
	'info_comment_lire_tableau' => 'Wéi een dës Tabell liese soll',
	'info_forum_statistiques' => 'Statistik vun de Visiten',
	'info_popularite_2' => 'Beléiftheet vum Site:',
	'info_popularite_3' => 'Beléiftheet: @popularite@; Visiten: @visites@',
	'info_popularite_5' => 'Beléiftheet:',
	'info_previsions' => 'Prognos:',
	'info_question_vignettes_referer' => 'Wann dir d’Statistik kuckt kënnt dir e Screenshot vun den Urspronks-Site gesinn', # MODIF
	'info_question_vignettes_referer_oui' => 'Screenshot vun den Urspronks-Site weisen',
	'info_visites' => 'Visiten:',
	'info_visites_plus_populaires' => 'Visite weisen fir <b>déi beléifsten</b> a fir <b>déi läscht verëffentlecht</b> Artikelen:',
	'info_zoom' => 'Zoom',
	'item_gerer_statistiques' => 'D’Statistik vun de Visite verwalten',

	// O
	'onglet_origine_visites' => 'Urspronk vun de Visiten',
	'onglet_repartition_debut' => 'zënter dem Ufank',
	'onglet_repartition_lang' => 'Verdeelung no Sprooch',

	// R
	'resume' => 'Zesummefaassung',

	// T
	'texte_admin_effacer_stats' => 'Dës Prozedur läscht d’Statistik an d’Beléiftheet vun den Artikele vum Site.',
	'texte_admin_effacer_toutes_stats' => 'Den 1. Knäppche läscht all d’Statistiken: Visiten, Beléiftheet vun den Artikelen a Linken déi erakommen.',
	'texte_comment_lire_tableau' => 'D’Plaz vum Artikel am Klassement no Beléiftheet steet am Rand; d’Beléiftheet vum Artikel (eng Prognos vun der Zuel vun de Visite pro Dag wann et esou weidergeet) an d’Zuel vun de Visite zënter Ufank stinn an der Erklärung déi erschéngt wann dir mat der Maus iwwer den Titel fuert.',
	'texte_signification' => 'Déi kumuléiert Date sinn donkel (Total vun den Ënner-Rubriken), d’Zuel vun de Visite fir all Rubrik sinn hell.',
	'titre_evolution_visite' => 'Entwécklung vun de Visiten',
	'titre_liens_entrants' => 'Linken déi era komm sinn',
	'titre_page_statistiques' => 'Statistik pro Rubrik',
	'titre_page_statistiques_visites' => 'Statistik vun de Visiten',

	// V
	'visites_journalieres' => 'Zuel vun de Visite pro Dag',
	'visites_mensuelles' => 'Zuel vun de Visite pro Mount'
);

==> spip_4.4.9+dfsg.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_lb.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=lb
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_effacer_referers' => 'Nëmmen d’Linken déi erakomme läschen',
	'bouton_effacer_statistiques' => 'All d’Statistike läschen',

	// C
	'csv' => 'CSV',

	// I
	'icone_evolution_visites' => 'Entwécklung vun de Visiten<br />@visites@ Visiten',
	'icone_repartition_actuelle' => 'Déi aktuell Verdeelung weisen',
	'icone_repartition_visites' => 'Verdeelung vun de Visiten',
	'icone_statistiques_visites' => 'Statistik',
	'info_affichier_visites_articles_plus_visites' => 'D’Visite fir <b>déi am meeschte gefroten Artikelen zënter dem Ufank</b> weisen:',
	'info_comment_lire_tableau' => 'Wéi een dës Tabell liese soll',
	'info_forum_statistiques' => 'Statistik vun de Visiten',
	'info_popularite_2' => 'Beléiftheet vum Site:',
	'info_popularite_3' => 'Beléiftheet: @popularite@; Visiten: @visites@',
	'info_popularite_5' => 'Beléiftheet:',
	'info_previsions' => 'Prognos:',
	'info_question_vignettes_referer' => 'Wann dir d’Statistik kuckt kënnt dir e Screenshot vun den Urspronks-Site gesinn', # MODIF
	'info_question_vignettes_referer_oui' => 'Screenshot vun den Urspronks-Site weisen',
	'info_visites' => 'Visiten:',
	'info_visites_plus_populaires' => 'Visite weisen fir <b>déi beléifsten</b> a fir <b>déi läscht verëffentlecht</b> Artikelen:',
	'info_zoom' => 'Zoom',
	'item_gerer_statistiques' => 'D’Statistik vun de Visite verwalten',

	// O
	'onglet_origine_visites' => 'Urspronk vun de Visiten',
	'onglet_repartition_debut' => 'zënter dem Ufank',
	'onglet_repartition_lang' => 'Verdeelung no Sprooch',

	// R
	'resume' => 'Zesummefaassung',

	// T
	'texte_admin_effacer_stats' => 'Dës Prozedur läscht d’Statistik an d’Beléiftheet vun den Artikele vum Site.',
	'texte_admin_effacer_toutes_stats' => 'Den 1. Knäppche läscht all d’Statistiken: Visiten, Beléiftheet vun den Artikelen a Linken déi erakommen.',
	'texte_comment_lire_tableau' => 'D’Plaz vum Artikel am Klassement no Beléiftheet steet am Rand; d’Beléiftheet vum Artikel (eng Prognos vun der Zuel vun de Visite pro Dag wann et esou weidergeet) an d’Zuel vun de Visite zënter Ufank stinn an der Erklärung déi erschéngt wann dir mat der Maus iwwer den Titel fuert.',
	'texte_signification' => 'Déi kumuléiert Date sinn donkel (Total vun den Ënner-Rubriken), d’Zuel vun de Visite fir all Rubrik sinn hell.',
	'titre_evolution_visite' => 'Entwécklung vun de Visiten',
	'titre_liens_entrants' => 'Linken déi era komm sinn',
	'titre_page_statistiques' => 'Statistik pro Rubrik',
	'titre_page_statistiques_visites' => 'Statistik vun de Visiten',

	// V
	'visites_journalieres' => 'Zuel vun de Visite pro Dag',
	'visites_mensuelles' => 'Zuel vun de Visite pro Mount',
];
